@@ -6,24 +6,28 @@
 
 module Main where
 
-import Aztecs.ECS
-import qualified Aztecs.ECS.Query as Q
-import qualified Aztecs.ECS.World as W
+import Aztecs
+import qualified Aztecs.World as W
 import Control.Monad.IO.Class
 
 newtype Position = Position Int
   deriving (Show, Eq)
 
+instance (Monad m) => Component m Position where
+  type ComponentStorage m Position = SparseStorage m
+
 newtype Velocity = Velocity Int
   deriving (Show, Eq)
 
+instance (Monad m) => Component m Velocity where
+  type ComponentStorage m Velocity = SparseStorage m
+
 data MoveSystem = MoveSystem
 
 instance (PrimMonad m, MonadIO m) => System m MoveSystem where
-  type SystemInputs m MoveSystem = Query m (W m Position, R Velocity)
-  runSystem MoveSystem q = do
-    results <- Q.runQuery q
-    mapM_ go results
+  type SystemIn m MoveSystem = Query (W m Position, R Velocity)
+
+  runSystem _ = mapM_ go
     where
       go (posRef, R (Velocity v)) = do
         modifyW posRef $ \(Position p) -> Position (p + v)
@@ -38,4 +42,4 @@ main = do
   where
     go = do
       _ <- spawn (bundle (Position 0) <> bundle (Velocity 1))
-      runSystemWithWorld MoveSystem
+      system MoveSystem
